pub enum Error<T: Debug> {
Io(Error),
Encoding(Utf8Error),
Incomplete(T),
}Expand description
Result of calling ReadExt::lines_rc
Variants
Io(Error)
Forwarded Errors from the underlying reader
Encoding(Utf8Error)
If a line contains any invalid UTF8 character
Incomplete(T)
If the provided buffer is full, it’s content is returned as Incomplete.
The rest of the line, including the last part containing the linebreak, will all be Incomplete or other errors.